@@ -55,7 +55,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from packageurl import PackageURL
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class BomMetaData:
     """
     This is our internal representation of the metadata complex type within the CycloneDX standard.
@@ -87,13 +87,8 @@ class BomMetaData:
         self.properties = properties or []
         self.manufacturer = manufacturer
         self.lifecycles = lifecycles or []
-
+        # deprecated properties below
         self.manufacture = manufacture
-        if manufacture:
-            warn(
-                '`bom.metadata.manufacture` is deprecated from CycloneDX v1.6 onwards. '
-                'Please use `bom.metadata.component.manufacturer` instead.',
-                DeprecationWarning)
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
@@ -214,6 +209,11 @@ class BomMetaData:
         @todo Based on https://github.com/CycloneDX/specification/issues/346,
               we should set this data on `.component.manufacturer`.
         """
+        if manufacture is not None:
+            warn(
+                '`bom.metadata.manufacture` is deprecated from CycloneDX v1.6 onwards. '
+                'Please use `bom.metadata.component.manufacturer` instead.',
+                DeprecationWarning)
         self._manufacture = manufacture
 
     @property
@@ -314,7 +314,12 @@ class BomMetaData:
         return f'<BomMetaData timestamp={self.timestamp}, component={self.component}>'
 
 
-@serializable.serializable_class(ignore_during_deserialization=['$schema', 'bom_format', 'spec_version'])
+@serializable.serializable_class(
+    ignore_during_deserialization={
+        '$schema', 'bom_format', 'spec_version',  # JSON-implementation's format hints
+    },
+    ignore_unknown_during_deserialization=True
+)
 class Bom:
     """
     This is our internal representation of a bill-of-materials (BOM).
