@@ -16,19 +16,21 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import re
+from collections.abc import Iterable
 from enum import Enum
 from os.path import exists
-from typing import Any, Dict, FrozenSet, Iterable, Optional, Set, Type, Union
+from typing import Any, Optional, Union
 from warnings import warn
 
 # See https://github.com/package-url/packageurl-python/issues/65
-import serializable
+import py_serializable as serializable
 from packageurl import PackageURL
 from sortedcontainers import SortedSet
 
+from .._internal.bom_ref import bom_ref_from_str as _bom_ref_from_str
 from .._internal.compare import ComparablePackageURL as _ComparablePackageURL, ComparableTuple as _ComparableTuple
 from .._internal.hash import file_sha1sum as _file_sha1sum
-from ..exception.model import InvalidOmniBorIdException, InvalidSwhidException, NoPropertiesProvidedException
+from ..exception.model import InvalidOmniBorIdException, InvalidSwhidException
 from ..exception.serialization import (
     CycloneDxDeserializationException,
     SerializationOfUnexpectedValueException,
@@ -43,10 +45,9 @@ from ..schema.schema import (
     SchemaVersion1Dot5,
     SchemaVersion1Dot6,
 )
-from ..serialization import BomRefHelper, LicenseRepositoryHelper, PackageUrl as PackageUrlSH
+from ..serialization import PackageUrl as PackageUrlSH
 from . import (
     AttachedText,
-    Copyright,
     ExternalReference,
     HashAlgorithm,
     HashType,
@@ -56,21 +57,22 @@ from . import (
     _HashTypeRepositorySerializationHelper,
 )
 from .bom_ref import BomRef
+from .component_evidence import ComponentEvidence, _ComponentEvidenceSerializationHelper
 from .contact import OrganizationalContact, OrganizationalEntity
 from .crypto import CryptoProperties
 from .dependency import Dependable
 from .issue import IssueType
-from .license import License, LicenseRepository
+from .license import License, LicenseRepository, _LicenseRepositorySerializationHelper
 from .release_note import ReleaseNotes
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Commit:
     """
     Our internal representation of the `commitType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_commitType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_commitType
     """
 
     def __init__(
@@ -81,11 +83,6 @@ class Commit:
         committer: Optional[IdentifiableAction] = None,
         message: Optional[str] = None,
     ) -> None:
-        if not uid and not url and not author and not committer and not message:
-            raise NoPropertiesProvidedException(
-                'At least one of `uid`, `url`, `author`, `committer` or `message` must be provided for a `Commit`.'
-            )
-
         self.uid = uid
         self.url = url
         self.author = author
@@ -170,135 +167,37 @@ class Commit:
     def message(self, message: Optional[str]) -> None:
         self._message = message
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.uid, self.url,
+            self.author, self.committer,
+            self.message
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Commit):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Commit):
-            return _ComparableTuple((
-                self.uid, self.url, self.author, self.committer, self.message
-            )) < _ComparableTuple((
-                other.uid, other.url, other.author, other.committer, other.message
-            ))
+            return self.__comparable_tuple() < other.__comparable_tuple()
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash((self.uid, self.url, self.author, self.committer, self.message))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Commit uid={self.uid}, url={self.url}, message={self.message}>'
 
 
-@serializable.serializable_class
-class ComponentEvidence:
-    """
-    Our internal representation of the `componentEvidenceType` complex type.
-
-    Provides the ability to document evidence collected through various forms of extraction or analysis.
-
-    .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_componentEvidenceType
-    """
-
-    def __init__(
-        self, *,
-        licenses: Optional[Iterable[License]] = None,
-        copyright: Optional[Iterable[Copyright]] = None,
-    ) -> None:
-        if not licenses and not copyright:
-            raise NoPropertiesProvidedException(
-                'At least one of `licenses` or `copyright` must be supplied for a `ComponentEvidence`.'
-            )
-
-        self.licenses = licenses or []  # type:ignore[assignment]
-        self.copyright = copyright or []  # type:ignore[assignment]
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(1)
-    # def identity(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @identity.setter
-    # def identity(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(2)
-    # def occurrences(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @occurrences.setter
-    # def occurrences(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    # @property
-    # ...
-    # @serializable.view(SchemaVersion1Dot5)
-    # @serializable.xml_sequence(3)
-    # def callstack(self) -> ...:
-    #    ... # TODO since CDX1.5
-    #
-    # @callstack.setter
-    # def callstack(self, ...) -> None:
-    #    ... # TODO since CDX1.5
-
-    @property
-    @serializable.type_mapping(LicenseRepositoryHelper)
-    @serializable.xml_sequence(4)
-    def licenses(self) -> LicenseRepository:
-        """
-        Optional list of licenses obtained during analysis.
-
-        Returns:
-            Set of `LicenseChoice`
-        """
-        return self._licenses
-
-    @licenses.setter
-    def licenses(self, licenses: Iterable[License]) -> None:
-        self._licenses = LicenseRepository(licenses)
-
-    @property
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'text')
-    @serializable.xml_sequence(5)
-    def copyright(self) -> 'SortedSet[Copyright]':
-        """
-        Optional list of copyright statements.
-
-        Returns:
-             Set of `Copyright`
-        """
-        return self._copyright
-
-    @copyright.setter
-    def copyright(self, copyright: Iterable[Copyright]) -> None:
-        self._copyright = SortedSet(copyright)
-
-    def __eq__(self, other: object) -> bool:
-        if isinstance(other, ComponentEvidence):
-            return hash(other) == hash(self)
-        return False
-
-    def __hash__(self) -> int:
-        return hash((tuple(self.licenses), tuple(self.copyright)))
-
-    def __repr__(self) -> str:
-        return f'<ComponentEvidence id={id(self)}>'
-
-
 @serializable.serializable_enum
 class ComponentScope(str, Enum):
     """
     Enum object that defines the permissable 'scopes' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.3/#type_scope
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_scope
     """
     # see `_ComponentScopeSerializationHelper.__CASES` for view/case map
     REQUIRED = 'required'
@@ -309,7 +208,7 @@ class ComponentScope(str, Enum):
 class _ComponentScopeSerializationHelper(serializable.helpers.BaseHelper):
     """  THIS CLASS IS NON-PUBLIC API  """
 
-    __CASES: Dict[Type[serializable.ViewType], FrozenSet[ComponentScope]] = dict()
+    __CASES: dict[type[serializable.ViewType], frozenset[ComponentScope]] = dict()
     __CASES[SchemaVersion1Dot0] = frozenset({
         ComponentScope.REQUIRED,
         ComponentScope.OPTIONAL,
@@ -324,21 +223,21 @@ class _ComponentScopeSerializationHelper(serializable.helpers.BaseHelper):
     __CASES[SchemaVersion1Dot6] = __CASES[SchemaVersion1Dot5]
 
     @classmethod
-    def __normalize(cls, cs: ComponentScope, view: Type[serializable.ViewType]) -> Optional[str]:
+    def __normalize(cls, cs: ComponentScope, view: type[serializable.ViewType]) -> Optional[str]:
         return cs.value \
             if cs in cls.__CASES.get(view, ()) \
             else None
 
     @classmethod
     def json_normalize(cls, o: Any, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
 
     @classmethod
     def xml_normalize(cls, o: Any, *,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
@@ -354,7 +253,7 @@ class ComponentType(str, Enum):
     Enum object that defines the permissible 'types' for a Component according to the CycloneDX schema.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.3/#type_classification
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_classification
     """
     # see `_ComponentTypeSerializationHelper.__CASES` for view/case map
     APPLICATION = 'application'
@@ -375,7 +274,7 @@ class ComponentType(str, Enum):
 class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
     """  THIS CLASS IS NON-PUBLIC API  """
 
-    __CASES: Dict[Type[serializable.ViewType], FrozenSet[ComponentType]] = dict()
+    __CASES: dict[type[serializable.ViewType], frozenset[ComponentType]] = dict()
     __CASES[SchemaVersion1Dot0] = frozenset({
         ComponentType.APPLICATION,
         ComponentType.DEVICE,
@@ -403,21 +302,21 @@ class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
     }
 
     @classmethod
-    def __normalize(cls, ct: ComponentType, view: Type[serializable.ViewType]) -> Optional[str]:
+    def __normalize(cls, ct: ComponentType, view: type[serializable.ViewType]) -> Optional[str]:
         if ct in cls.__CASES.get(view, ()):
             return ct.value
         raise SerializationOfUnsupportedComponentTypeException(f'unsupported {ct!r} for view {view!r}')
 
     @classmethod
     def json_normalize(cls, o: Any, *,
-                       view: Optional[Type[serializable.ViewType]],
+                       view: Optional[type[serializable.ViewType]],
                        **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
 
     @classmethod
     def xml_normalize(cls, o: Any, *,
-                      view: Optional[Type[serializable.ViewType]],
+                      view: Optional[type[serializable.ViewType]],
                       **__: Any) -> Optional[str]:
         assert view is not None
         return cls.__normalize(o, view)
@@ -427,13 +326,13 @@ class _ComponentTypeSerializationHelper(serializable.helpers.BaseHelper):
         return ComponentType(o)
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Diff:
     """
     Our internal representation of the `diffType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_diffType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_diffType
     """
 
     def __init__(
@@ -441,11 +340,6 @@ class Diff:
         text: Optional[AttachedText] = None,
         url: Optional[XsUri] = None,
     ) -> None:
-        if not text and not url:
-            raise NoPropertiesProvidedException(
-                'At least one of `text` or `url` must be provided for a `Diff`.'
-            )
-
         self.text = text
         self.url = url
 
@@ -477,22 +371,24 @@ class Diff:
     def url(self, url: Optional[XsUri]) -> None:
         self._url = url
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.url,
+            self.text,
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Diff):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Diff):
-            return _ComparableTuple((
-                self.url, self.text
-            )) < _ComparableTuple((
-                other.url, other.text
-            ))
+            return self.__comparable_tuple() < other.__comparable_tuple()
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash((self.text, self.url))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Diff url={self.url}>'
@@ -504,7 +400,7 @@ class PatchClassification(str, Enum):
     Enum object that defines the permissible `patchClassification`s.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_patchClassification
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_patchClassification
     """
     BACKPORT = 'backport'
     CHERRY_PICK = 'cherry-pick'
@@ -512,13 +408,13 @@ class PatchClassification(str, Enum):
     UNOFFICIAL = 'unofficial'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Patch:
     """
     Our internal representation of the `patchType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_patchType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_patchType
     """
 
     def __init__(
@@ -529,7 +425,7 @@ class Patch:
     ) -> None:
         self.type = type
         self.diff = diff
-        self.resolves = resolves or []  # type:ignore[assignment]
+        self.resolves = resolves or []
 
     @property
     @serializable.xml_attribute()
@@ -579,28 +475,30 @@ class Patch:
     def resolves(self, resolves: Iterable[IssueType]) -> None:
         self._resolves = SortedSet(resolves)
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.type, self.diff,
+            _ComparableTuple(self.resolves)
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Patch):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Patch):
-            return _ComparableTuple((
-                self.type, self.diff, _ComparableTuple(self.resolves)
-            )) < _ComparableTuple((
-                other.type, other.diff, _ComparableTuple(other.resolves)
-            ))
+            return self.__comparable_tuple() < other.__comparable_tuple()
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash((self.type, self.diff, tuple(self.resolves)))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Patch type={self.type}, id={id(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Pedigree:
     """
     Our internal representation of the `pedigreeType` complex type.
@@ -611,7 +509,7 @@ class Pedigree:
     may not be known.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_pedigreeType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_pedigreeType
     """
 
     def __init__(
@@ -623,17 +521,11 @@ class Pedigree:
         patches: Optional[Iterable[Patch]] = None,
         notes: Optional[str] = None,
     ) -> None:
-        if not ancestors and not descendants and not variants and not commits and not patches and not notes:
-            raise NoPropertiesProvidedException(
-                'At least one of `ancestors`, `descendants`, `variants`, `commits`, `patches` or `notes` must be '
-                'provided for `Pedigree`'
-            )
-
-        self.ancestors = ancestors or []  # type:ignore[assignment]
-        self.descendants = descendants or []  # type:ignore[assignment]
-        self.variants = variants or []  # type:ignore[assignment]
-        self.commits = commits or []  # type:ignore[assignment]
-        self.patches = patches or []  # type:ignore[assignment]
+        self.ancestors = ancestors or []
+        self.descendants = descendants or []
+        self.variants = variants or []
+        self.commits = commits or []
+        self.patches = patches or []
         self.notes = notes
 
     @property
@@ -747,28 +639,35 @@ class Pedigree:
     def notes(self, notes: Optional[str]) -> None:
         self._notes = notes
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            _ComparableTuple(self.ancestors),
+            _ComparableTuple(self.descendants),
+            _ComparableTuple(self.variants),
+            _ComparableTuple(self.commits),
+            _ComparableTuple(self.patches),
+            self.notes
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Pedigree):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((
-            tuple(self.ancestors), tuple(self.descendants), tuple(self.variants), tuple(self.commits),
-            tuple(self.patches), self.notes
-        ))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Pedigree id={id(self)}, hash={hash(self)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swid:
     """
     Our internal representation of the `swidType` complex type.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.4/xml/#type_swidType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/xml/#type_swidType
     """
 
     def __init__(
@@ -892,19 +791,29 @@ class Swid:
     def url(self, url: Optional[XsUri]) -> None:
         self._url = url
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.tag_id,
+            self.name, self.version,
+            self.tag_version,
+            self.patch,
+            self.url,
+            self.text,
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Swid):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __hash__(self) -> int:
-        return hash((self.tag_id, self.name, self.version, self.tag_version, self.patch, self.text, self.url))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Swid tagId={self.tag_id}, name={self.name}, version={self.version}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class OmniborId(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -945,7 +854,7 @@ class OmniborId(serializable.helpers.BaseHelper):
 
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, OmniborId):
-            return hash(other) == hash(self)
+            return self._id == other._id
         return False
 
     def __lt__(self, other: Any) -> bool:
@@ -963,7 +872,7 @@ class OmniborId(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Swhid(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -1004,7 +913,7 @@ class Swhid(serializable.helpers.BaseHelper):
 
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, Swhid):
-            return hash(other) == hash(self)
+            return self._id == other._id
         return False
 
     def __lt__(self, other: Any) -> bool:
@@ -1022,13 +931,13 @@ class Swhid(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Component(Dependable):
     """
     This is our internal representation of a Component within a Bom.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.3/#type_component
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_component
     """
 
     @staticmethod
@@ -1097,44 +1006,35 @@ class Component(Dependable):
     ) -> None:
         self.type = type
         self.mime_type = mime_type
-        if isinstance(bom_ref, BomRef):
-            self._bom_ref = bom_ref
-        else:
-            self._bom_ref = BomRef(value=str(bom_ref) if bom_ref else None)
+        self._bom_ref = _bom_ref_from_str(bom_ref)
         self.supplier = supplier
         self.manufacturer = manufacturer
-        self.authors = authors or []  # type:ignore[assignment]
-        self.author = author
+        self.authors = authors or []
         self.publisher = publisher
         self.group = group
         self.name = name
-        self.version = version
         self.description = description
         self.scope = scope
-        self.hashes = hashes or []  # type:ignore[assignment]
-        self.licenses = licenses or []  # type:ignore[assignment]
+        self.hashes = hashes or []
+        self.licenses = licenses or []
         self.copyright = copyright
         self.cpe = cpe
         self.purl = purl
-        self.omnibor_ids = omnibor_ids or []  # type:ignore[assignment]
-        self.swhids = swhids or []  # type:ignore[assignment]
+        self.omnibor_ids = omnibor_ids or []
+        self.swhids = swhids or []
         self.swid = swid
-        self.modified = modified
         self.pedigree = pedigree
-        self.external_references = external_references or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
-        self.components = components or []  # type:ignore[assignment]
+        self.external_references = external_references or []
+        self.properties = properties or []
+        self.components = components or []
         self.evidence = evidence
         self.release_notes = release_notes
         self.crypto_properties = crypto_properties
-        self.tags = tags or []  # type:ignore[assignment]
-
-        if modified:
-            warn('`.component.modified` is deprecated from CycloneDX v1.3 onwards. '
-                 'Please use `@.pedigree` instead.', DeprecationWarning)
-        if author:
-            warn('`.component.author` is deprecated from CycloneDX v1.6 onwards. '
-                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
+        self.tags = tags or []
+        # spec-deprecated properties below
+        self.author = author
+        self.modified = modified
+        self.version = version
 
     @property
     @serializable.type_mapping(_ComponentTypeSerializationHelper)
@@ -1173,7 +1073,7 @@ class Component(Dependable):
 
     @property
     @serializable.json_name('bom-ref')
-    @serializable.type_mapping(BomRefHelper)
+    @serializable.type_mapping(BomRef)
     @serializable.view(SchemaVersion1Dot1)
     @serializable.view(SchemaVersion1Dot2)
     @serializable.view(SchemaVersion1Dot3)
@@ -1187,8 +1087,6 @@ class Component(Dependable):
         An optional identifier which can be used to reference the component elsewhere in the BOM. Every bom-ref MUST be
         unique within the BOM.
 
-        If a value was not provided in the constructor, a UUIDv4 will have been assigned.
-
         Returns:
             `BomRef`
         """
@@ -1271,6 +1169,9 @@ class Component(Dependable):
 
     @author.setter
     def author(self, author: Optional[str]) -> None:
+        if author is not None:
+            warn('`@.author` is deprecated from CycloneDX v1.6 onwards. '
+                 'Please use `@.authors` or `@.manufacturer` instead.', DeprecationWarning)
         self._author = author
 
     @property
@@ -1351,7 +1252,7 @@ class Component(Dependable):
     @version.setter
     def version(self, version: Optional[str]) -> None:
         if version and len(version) > 1024:
-            warn('`.component.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
+            warn('`@.version`has a maximum length of 1024 from CycloneDX v1.6 onwards.', UserWarning)
         self._version = version
 
     @property
@@ -1411,7 +1312,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot4)
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
-    @serializable.type_mapping(LicenseRepositoryHelper)
+    @serializable.type_mapping(_LicenseRepositorySerializationHelper)
     @serializable.xml_sequence(12)
     def licenses(self) -> LicenseRepository:
         """
@@ -1546,6 +1447,9 @@ class Component(Dependable):
 
     @modified.setter
     def modified(self, modified: bool) -> None:
+        if modified:
+            warn('`@.modified` is deprecated from CycloneDX v1.3 onwards. '
+                 'Please use `@.pedigree` instead.', DeprecationWarning)
         self._modified = modified
 
     @property
@@ -1638,6 +1542,7 @@ class Component(Dependable):
     @serializable.view(SchemaVersion1Dot5)
     @serializable.view(SchemaVersion1Dot6)
     @serializable.xml_sequence(24)
+    @serializable.type_mapping(_ComponentEvidenceSerializationHelper)
     def evidence(self) -> Optional[ComponentEvidence]:
         """
         Provides the ability to document evidence collected through various forms of extraction or analysis.
@@ -1729,7 +1634,7 @@ class Component(Dependable):
     def tags(self, tags: Iterable[str]) -> None:
         self._tags = SortedSet(tags)
 
-    def get_all_nested_components(self, include_self: bool = False) -> Set['Component']:
+    def get_all_nested_components(self, include_self: bool = False) -> set['Component']:
         components = set()
         if include_self:
             components.add(self)
@@ -1745,52 +1650,36 @@ class Component(Dependable):
         else:
             return f'https://pypi.org/project/{self.name}'
 
+    def __comparable_tuple(self) -> _ComparableTuple:
+        return _ComparableTuple((
+            self.type, self.group, self.name, self.version,
+            self.bom_ref.value,
+            None if self.purl is None else _ComparablePackageURL(self.purl),
+            self.swid, self.cpe, _ComparableTuple(self.swhids),
+            self.supplier, self.author, self.publisher,
+            self.description,
+            self.mime_type, self.scope, _ComparableTuple(self.hashes),
+            _ComparableTuple(self.licenses), self.copyright,
+            self.pedigree,
+            _ComparableTuple(self.external_references), _ComparableTuple(self.properties),
+            _ComparableTuple(self.components), self.evidence, self.release_notes, self.modified,
+            _ComparableTuple(self.authors), _ComparableTuple(self.omnibor_ids), self.manufacturer,
+            self.crypto_properties, _ComparableTuple(self.tags),
+        ))
+
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Component):
-            return hash(other) == hash(self)
+            return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
     def __lt__(self, other: Any) -> bool:
         if isinstance(other, Component):
-            return _ComparableTuple((
-                self.type, self.group, self.name, self.version,
-                self.mime_type, self.supplier, self.author, self.publisher,
-                self.description, self.scope, _ComparableTuple(self.hashes),
-                _ComparableTuple(self.licenses), self.copyright, self.cpe,
-                None if self.purl is None else _ComparablePackageURL(self.purl),
-                self.swid, self.pedigree,
-                _ComparableTuple(self.external_references), _ComparableTuple(self.properties),
-                _ComparableTuple(self.components), self.evidence, self.release_notes, self.modified,
-                _ComparableTuple(self.authors), _ComparableTuple(self.omnibor_ids), self.manufacturer,
-                _ComparableTuple(self.swhids), self.crypto_properties, _ComparableTuple(self.tags)
-            )) < _ComparableTuple((
-                other.type, other.group, other.name, other.version,
-                other.mime_type, other.supplier, other.author, other.publisher,
-                other.description, other.scope, _ComparableTuple(other.hashes),
-                _ComparableTuple(other.licenses), other.copyright, other.cpe,
-                None if other.purl is None else _ComparablePackageURL(other.purl),
-                other.swid, other.pedigree,
-                _ComparableTuple(other.external_references), _ComparableTuple(other.properties),
-                _ComparableTuple(other.components), other.evidence, other.release_notes, other.modified,
-                _ComparableTuple(other.authors), _ComparableTuple(other.omnibor_ids), other.manufacturer,
-                _ComparableTuple(other.swhids), other.crypto_properties, _ComparableTuple(other.tags)
-            ))
+            return self.__comparable_tuple() < other.__comparable_tuple()
         return NotImplemented
 
     def __hash__(self) -> int:
-        return hash((
-            self.type, self.group, self.name, self.version,
-            self.mime_type, self.supplier, self.author, self.publisher,
-            self.description, self.scope, tuple(self.hashes),
-            tuple(self.licenses), self.copyright, self.cpe,
-            self.purl,
-            self.swid, self.pedigree,
-            tuple(self.external_references), tuple(self.properties),
-            tuple(self.components), self.evidence, self.release_notes, self.modified,
-            tuple(self.authors), tuple(self.omnibor_ids), self.manufacturer,
-            tuple(self.swhids), self.crypto_properties, tuple(self.tags)
-        ))
+        return hash(self.__comparable_tuple())
 
     def __repr__(self) -> str:
         return f'<Component bom-ref={self.bom_ref!r}, group={self.group}, name={self.name}, ' \
-               f'version={self.version}, type={self.type}>'
+            f'version={self.version}, type={self.type}>'
